==> CSS-Sass-3.3.5.tar.gz: CSS-Sass-3.3.5/libsass/docs/implementations.md <==
There are several implementations of `libsass` for a variety of languages. Here are just a few of them. Note, some implementations may or may not be up to date. We have not verified whether they work.

### C
* [sassc](https://github.com/hcatlin/sassc)

### Go
* [go-libsass](https://github.com/wellington/go-libsass)
* [go_sass](https://github.com/suapapa/go_sass)
* [go-sass](https://github.com/SamWhited/go-sass)

### Lua
* [lua-sass](https://github.com/craigbarnes/lua-sass)

### .NET
* [libsass-net](https://github.com/darrenkopp/libsass-net)
* [NSass](https://github.com/TBAPI-0KA/NSass)
* [Sass.Net](https://github.com/andyalm/Sass.Net)

### node.js
* [node-sass](https://github.com/andrew/node-sass)

### Java
* [libsass-maven-plugin](https://github.com/warmuuh/libsass-maven-plugin)
* [jsass](https://github.com/bit3/jsass)

### JavaScript
* [sass.js](https://github.com/medialize/sass.js)

### Perl
* [CSS::Sass](https://github.com/caldwell/CSS-Sass)
* [Text::Sass::XS](https://github.com/ysasaki/Text-Sass-XS)

### PHP
* [sassphp](https://github.com/sensational/sassphp)

### Python
* [libsass-python](https://github.com/dahlia/libsass-python)
* [SassPython](https://github.com/marianoguerra/SassPython)
* [pylibsass](https://github.com/rsenk330/pylibsass)
* [python-scss](https://github.com/pistolero/python-scss)

### Ruby
* [sassruby](https://github.com/hcatlin/sassruby)

### Scala
* [Sass-Scala](https://github.com/kkung/Sass-Scala)

### Tcl
* [tclsass](https://github.com/flightaware/tclsass)

==> CSS-Sass-3.4.1.tar.gz: CSS-Sass-3.4.1/libsass/docs/implementations.md <==
There are several implementations of `libsass` for a variety of languages. Here are just a few of them. Note, some implementations may or may not be up to date. We have not verified whether they work.

### C
* [sassc](https://github.com/hcatlin/sassc)

### Elixir
* [sass.ex](https://github.com/scottdavis/sass.ex)

### Go
* [go-libsass](https://github.com/wellington/go-libsass)
* [go_sass](https://github.com/suapapa/go_sass)
* [go-sass](https://github.com/SamWhited/go-sass)

### Lua
* [lua-sass](https://github.com/craigbarnes/lua-sass)

### .NET
* [libsass-net](https://github.com/darrenkopp/libsass-net)
* [NSass](https://github.com/TBAPI-0KA/NSass)
* [Sass.Net](https://github.com/andyalm/Sass.Net)

### node.js
* [node-sass](https://github.com/andrew/node-sass)

### Java
* [libsass-maven-plugin](https://github.com/warmuuh/libsass-maven-plugin)
* [jsass](https://github.com/bit3/jsass)

### JavaScript
* [sass.js](https://github.com/medialize/sass.js)

### Perl
* [CSS::Sass](https://github.com/caldwell/CSS-Sass)
* [Text::Sass::XS](https://github.com/ysasaki/Text-Sass-XS)

### PHP
* [sassphp](https://github.com/sensational/sassphp)
* [php-sass](https://github.com/lesstif/php-sass)

### Python
* [libsass-python](https://github.com/dahlia/libsass-python)
* [SassPython](https://github.com/marianoguerra/SassPython)
* [pylibsass](https://github.com/rsenk330/pylibsass)
* [python-scss](https://github.com/pistolero/python-scss)

### Ruby
* [sassruby](https://github.com/hcatlin/sassruby)

### Scala
* [Sass-Scala](https://github.com/kkung/Sass-Scala)

### Tcl
* [tclsass](https://github.com/flightaware/tclsass)
